var Lighter = {
    name: 'Lighter',

    difficulties: {
        easy: {
            lines: 3,
            columns: 4,
        },
        normal: {
            lines: 4,
            columns: 5,
        },
        hard: {
            lines: 4,
            columns: 6,
        },
        extreme: {
            lines: 4,
            columns: 8,
        },
    },

    settings: {

    },

    game: {
        status: 0,
        field: null,
    },

    initialise: function() {
        this.startGame('easy');
    },

    startGame: function(difficulty) {
        this.settings = this.difficulties[difficulty];
        this.drawGameBoard();
        this.resetGame();
    },

    drawGameBoard: function() {

        /* Initialise l'affichage du resultat */
        document.getElementById('result').innerHTML = '';

        /* Dessine le plateau */
        board = document.getElementById('plateau');
        board.innerHTML = '';
        border = document.createElement('table');
        border.setAttribute('oncontextmenu', 'return false;');
        field = document.createElement('tbody');
        border.appendChild(field);
        border.className = 'field';
        board.appendChild(border);

        /* Dessine les cellules */
        for (i = 1; i <= this.settings['lines']; i++) {
            line = document.createElement('tr');

            for (j = 1; j <= this.settings['columns']; j++) {
                cell = document.createElement('td');
                cell.id = 'cell-'+i+'-'+j;
                cell.className = 'cell';
                cell.setAttribute('onclick', this.name+'.updatePosition('+i+', '+j+');');
                line.appendChild(cell);
            }
            field.appendChild(line);
        }
    },

    resetGame: function() {
        /* Creons le plateau, vide */
        this.game.field = new Array();
        for (i = 1; i <= this.settings['lines']; i++) {
            this.game.field[i] = new Array();
            for (j = 1; j <= this.settings['columns']; j++) {
                this.game.field[i][j] = 0;
            }
        }

        /* On definit le status au mode jeu */
        this.game.status = 1;
    },

    updatePosition: function(x, y) {
        /* Verifie que le jeu est actif */
        if (this.game.status == 0)
            return;

        /* Met a jour la cellule selectionnee */
        this.switchCell(x, y);

        /* Met a jour la cellule de gauche */
        this.switchCell(x-1, y);

        /* Met a jour la cellule de droite */
        this.switchCell(x+1, y);

        /* Met a jour la cellule de dessus */
        this.switchCell(x, y-1);

        /* Met a jour la cellule de dessous */
        this.switchCell(x, y+1);

        /* Verifie si la partie est gagnee */
        this.checkWin();
    },

    switchCell: function(x, y) {
        /* Verifie que la cellule existe */
        if (x >= 1 && x <= this.settings['lines'] && y >= 1 && y <= this.settings['columns']) {
            /* Inverse la valeur de la case en question */
            this.game.field[x][y] = Math.abs(this.game.field[x][y]-1);

            /* Met a jour l'affichage de la cellule */
            document.getElementById('cell-'+x+'-'+y).classList.toggle('marked');
        }
    },

    checkWin: function() {
        /* On verifie toutes les cases */
        for (var i = 1; i <= this.settings['lines']; i++) {
            for (var j = 1; j <= this.settings['columns']; j++) {
                /* On sort de la boucle, des que l'on trouve une case a 0 */
                if (this.game.field[i][j] == 0)
                    return false;
            }
        }

        /* Aucune case trouvee avec la valeur 0, la partie est gagnee */
        this.game.status = 0;

        /* On affiche la victoire */
        this.displayWin();
    },

    displayWin: function() {
        /* Affiche le resultat dans l'espace dedie, en couleur */
        document.getElementById('result').innerHTML = 'Gagn&eacute;';
        document.getElementById('result').style.color = '#43b456';

        /* Defini l'etat de la partie a termine */
        this.game.status = 0;
    },
};
